@@ -11,16 +11,17 @@
 #include <unistd.h>
 
 #include "apolloron.h"
+#include "apolloron_html_client.h"
 
 using namespace apolloron;
+using namespace apolloron_html_client;
 
 
 const char *INKF_PROGNAME = "inkf";
 const char *INKF_BRIEF    = "Yet Another Network Kanji Filter";
-const char *INKF_VERSION  = "1.0.2";
+const char *INKF_VERSION  = "1.0.3";
 const char *INKF_COPY     = "Copyright (C) 2002-2009 Tachibanamasashi";
 const char *INKF_DEF_OUT  = "inkf.out";
-const int REDIRECT_MAX = 10;
 
 typedef enum {
   MIME_NONE,
@@ -82,7 +83,7 @@ int main(int argc, char *argv[]) {
   FILE *fpin = stdin, *fpout = stdout;
   String tmp_str;
   char buf[4096 + 1];
-  int i, j, k, l;
+  int i, l;
 
   // set option
   if (!set_option(option, argc, (const char **)argv)) {
@@ -165,187 +166,19 @@ int main(int argc, char *argv[]) {
 
     // read from file(s) or specified URL
     for (i = 0; option.input_filenames[i] != '\0'; i++) {
-        if (charset_autodetect_pre) {
-          strcpy(option.input_charset, "AUTODETECT");
-	}
+      if (charset_autodetect_pre) {
+        strcpy(option.input_charset, "AUTODETECT");
+      }
 #if __OPENSSL == 1
       if (!strncasecmp(option.input_filenames[i], "http://", 7) ||
           !strncasecmp(option.input_filenames[i], "https://", 8)) {
 #else
       if (!strncasecmp(option.input_filenames[i], "http://", 7)) {
 #endif
-        char *url;
-        Socket tmp_socket;
-        char host[1024], port[20], path[1024], port_tmp[20];
-        char *p;
-        int host_base;
-        bool ssl;
-        bool charset_autodetect;
-        bool header_end;
-        bool ischunked;
-        long chunk_size;
-        int redirect_count;
-
-        redirect_count = 0;
-        url = new char [strlen(option.input_filenames[i]) + 1];
-        strcpy(url, option.input_filenames[i]);
-
-HTTP_START:
-#if __OPENSSL == 1
-        if (!strncasecmp(url, "http://", 7)) {
-#endif
-          strcpy(port, "80");
-          host_base = 7;
-          ssl = false;
-#if __OPENSSL == 1
-        } else {
-          strcpy(port, "443");
-          host_base = 8;
-          ssl = true;
-        }
-#endif
-        strncpy(host, url + host_base, 1023);
-        host[1023] = '\0';
-        p = strchr(host, '/');
-        if (p != NULL) {
-          *p = '\0';
-        }
-        p = strchr(host, ':');
-        if (p != NULL) {
-          *p = '\0';
-        }
-        port_tmp[0] = '\0';
-        p = url + host_base + strlen(host);
-        if (*p == ':') {
-          for (j = 0; p[1 + j] != '\0' && j < 19; j++) {
-            if (p[1 + 1] == '/') {
-              break;
-            }
-            port_tmp[j] = p[1 + j];
-          }
-          port_tmp[j] = '\0';
-        }
-        if (port_tmp[0] != '\0') {
-          strcpy(port, port_tmp);
-        }
-        p = strchr(url + host_base, '/');
-        strncpy(path, p?p:"/", 1023);
-        path[1023] = '\0';
-        delete [] url;
-        charset_autodetect = false;
-        if (charset_autodetect_pre) {
-          charset_autodetect = true;
-        }
-        tmp_socket.setTimeout(5);
-        tmp_socket.connect(host, port, ssl);
-        tmp_socket.send("GET ");
-        tmp_socket.send((*path)?path:"/");
-        tmp_socket.send(" HTTP/1.1\r\n");
-        tmp_socket.send("HOST: ");
-        tmp_socket.send(host);
-        tmp_socket.send("\r\n");
-        tmp_socket.send("User-Agent: Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; ");
-        tmp_socket.send(INKF_PROGNAME);
-        tmp_socket.send(" ");
-        tmp_socket.send(INKF_VERSION);
-        tmp_socket.send(")\r\n");
-        tmp_socket.send("CONNECTION: close\r\n\r\n");
-        tmp_str = "";
-        header_end = false;
-        ischunked = false;
-        chunk_size = -1;
-        while (tmp_socket.error() == 0 && tmp_socket.connected()) {
-          char *endptr;
-
-          tmp_socket.receiveLine();
-          if (tmp_socket.receivedData().len() == 0) {
-            break;
-          }
-
-          // redirect
-          if (!header_end &&
-              !strncasecmp(tmp_socket.receivedData().c_str(), "Location", 8) &&
-              8 <= tmp_socket.receivedData().search(":") &&
-              9 <= tmp_socket.receivedData().searchCase("http")) {
-            url = new char [tmp_socket.receivedData().len() + 1];
-            p = url;
-            p[0] = '\0';
-            j = 0;
-            for (j = 9; j < tmp_socket.receivedData().len(); j++) {
-              if (url[0] == '\0') {
-                if (!isspace(tmp_socket.receivedData()[j]) && tmp_socket.receivedData()[j] != ':') {
-                  *p = tmp_socket.receivedData()[j];
-                  p++;
-                }
-              } else if (!isspace(tmp_socket.receivedData()[j])) {
-                *p = tmp_socket.receivedData()[j];
-                p++;
-              }
-            }
-            *p = '\0';
-
-#if __OPENSSL == 1
-            if (!strncasecmp(url, "http://", 7) ||
-                !strncasecmp(url, "https://", 8)) {
-#else
-            if (!strncasecmp(url, "http://", 7)) {
-#endif
-              tmp_socket.clear();
-              redirect_count++;
-              if (redirect_count <= REDIRECT_MAX) {
-                goto HTTP_START;
-              }
-            }
-
-            delete [] url;
-          }
-
-          if (!header_end &&
-              !strncasecmp(tmp_socket.receivedData().c_str(), "Transfer-Encoding", 17) &&
-              17 <= tmp_socket.receivedData().search(":") &&
-              18 <= tmp_socket.receivedData().searchCase("chunked")) {
-            ischunked = true;
-          }
-
-          if (header_end && ischunked) {
-            if (tmp_socket.receivedData()[0] == '\n' || tmp_socket.receivedData() == "\r\n") {
-              continue;
-            }
-            chunk_size = strtol(tmp_socket.receivedData().c_str(), &endptr, 16);
-            if (chunk_size <= 0) {
-              continue;
-            }
-            tmp_socket.receive(chunk_size);
-            tmp_socket.receivedData().useAsText();
-          }
-
-          if (charset_autodetect && 0 <= (l = tmp_socket.receivedData().searchCase("charset="))) {
-            char charset[32], c;
-            k = 0;
-            while (k < 31) {
-              c = tmp_socket.receivedData()[l+8+k];
-              if (!(isalnum(c) || c == '-' || c == '_')) {
-                break;
-              }
-              charset[k] = c;
-              k++;
-            }
-            charset[k] = '\0';
-            if (0 < k) {
-              strcpy(option.input_charset, charset);
-              charset_autodetect = false;
-            }
-          }
-
-          if (header_end) {
-            tmp_str += tmp_socket.receivedData();
-          }
-
-          if (!header_end && (tmp_socket.receivedData()[0] == '\n' || tmp_socket.receivedData() == "\r\n")) {
-            header_end = true;
-          }
-        }
-        tmp_socket.clear();
+        HTMLClient hc;
+        tmp_str = hc.getURL(option.input_filenames[i]);
+        strncpy(option.input_charset, hc.getOrigCharset().c_str(), 31);
+        option.input_charset[31] = '\0';
       } else {
         tmp_str.loadFile(option.input_filenames[i]);
       }
@@ -435,11 +268,11 @@ bool set_option(TOption &option, int argc, const char **argv) {
       if (!strcasecmp(argv[i], "--guess")) {
         option.flag_guess = true;
       } else if (!strncasecmp(argv[i], "--ic=", 5)) {
-        strncpy(option.input_charset, argv[i]+5, 15);
-        option.input_charset[15] = '\0';
+        strncpy(option.input_charset, argv[i]+5, 31);
+        option.input_charset[31] = '\0';
       } else if (!strncasecmp(argv[i], "--oc=", 5)) {
-        strncpy(option.output_charset, argv[i]+5, 15);
-        option.output_charset[15] = '\0';
+        strncpy(option.output_charset, argv[i]+5, 31);
+        option.output_charset[31] = '\0';
       } else if (!strcasecmp(argv[i], "--overwrite")) {
         option.flag_overwrite = true;
       } else if (!strcasecmp(argv[i], "--html-to-plain")) {
