@@ -2,7 +2,7 @@
 /*! @file apolloron.h
     @brief Header file of libapolloron.
     @author Tachibanamasashi, Apolloron Project.
-    @date 2009-04-24
+    @date 2009-07-16
  ******************************************************************************/
 
 #ifndef _APOLLORON_H_
@@ -16,7 +16,7 @@ class Keys;
 
 /*! @brief Version of libapolloron.
  */
-#define LIBAPOLLORON_VERSION "0.43.1"
+#define LIBAPOLLORON_VERSION "0.43.5"
 
 
 /*----------------------------------------------------------------------------*/
@@ -26,7 +26,7 @@ class Keys;
  */ 
 class String {
 protected:
-  // nBinaryLength <= nMinimumSize <= nCapacity
+  // nBinaryLength <= nFixedLength <= nCapacity
   char *pText; // String
   long nLength; // Size of string
   long nCapacity; // Size of all allocated memory
@@ -66,7 +66,7 @@ public:
 
   // Memory size which carries out minimum allocation
   virtual long fixedLength() const;
-  virtual bool setFixedLength(long);
+  virtual bool setFixedLength(long size);
 
   // Reference of size as binary String
   virtual long binaryLength() const;
@@ -244,9 +244,14 @@ public:
   virtual String& encodeQuotedPrintable(long max_width = 72, const char * return_str = "\n", const char * prefix_str = (const char *)0, const char * suffix_str = (const char *)0) const;
   virtual String& decodeQuotedPrintable() const;
 
+  // Crypt / Decrypt
+  virtual String& crypt() const;
+  virtual String& decrypt() const;
+
   // MD5 digest key
   virtual String& md5() const;
   virtual String& hmacMd5(const String & key) const;
+  virtual String& cramMd5(const String & user, const String & challenge) const;
 
   // Plain text or HTML template convertion
   virtual String& evalText(Keys replace_keys) const;
@@ -390,7 +395,8 @@ public:
   virtual bool delKey(const char *key);
 
   // Files
-  virtual bool loadConfigFile(const char *filename);
+  virtual bool loadFile(const char *filename);
+  virtual bool saveFile(const char *filename) const;
 };
 
 
@@ -450,6 +456,7 @@ public:
   // Getting date and time
   virtual String &toString(const String &format);
 #define DATEFORMAT_RFC822  "%a, %02d %b %04Y %02H:%02M:%02S %z"
+#define DATEFORMAT_INTERNALDATE "%02d-%b-%04Y %02H:%02M:%02S %z"
 #define DATEFORMAT_ISO8601 "%04Y-%02m-%02dT%02H:%02M:%02S%Z"
   virtual const TDateTime &getDateTime() const;
   virtual const TDate &getDate() const;
