@@ -463,14 +463,15 @@ bool DateTime::set(const DateTime &datetime) {
     @param datetimestr String of date and time, like follows:
                    "2008-01-02T10:55:30+09:00" (ISO8601)
                    "Wed, 02 Jan 2008 10:55:30 +0900" (RFC822)
-                   "2008-01-02 10:55:30 +09:00" (ORIGINAL1)
+                   " 8-Jul-2009 10:32:11 +0900" (INTERNALDATE)
+		   "2008-01-02 10:55:30 +09:00" (ORIGINAL1)
                    "20080102105530+0900" (ORIGINAL2)
     @retval true  success
     @retval false failure
  */
 bool DateTime::set(const String &datetimestr) {
   long gmtoff;
-  enum {UNKNOWN, ISO8601, RFC822, ORIGINAL1, ORIGINAL2} datetime_format;
+  enum {UNKNOWN, ISO8601, RFC822, INTERNALDATE, ORIGINAL1, ORIGINAL2} datetime_format;
   struct tm tmp_time_tm;
   char buf[100];
   const char *cpstr, *p;
@@ -478,7 +479,7 @@ bool DateTime::set(const String &datetimestr) {
   int year;
 
   datetime_format = UNKNOWN;
-  cpstr = datetimestr.c_str();
+  cpstr = datetimestr.trim().c_str();
 
   // detecting type of date and time format
   for (i = 0; i < 7; i++) {
@@ -495,6 +496,21 @@ bool DateTime::set(const String &datetimestr) {
       }
     }
   }
+  if (datetime_format == UNKNOWN) {
+    for (i = 0; i < 12; i++) {
+      char amon[6];
+      amon[0] = '-';
+      amon[1] = AMONTH[i][0];
+      amon[2] = AMONTH[i][1];
+      amon[3] = AMONTH[i][2];
+      amon[4] = '-';
+      amon[5] = '\0';
+      if (strcasestr(cpstr, amon) != NULL) {
+        datetime_format = INTERNALDATE;
+        break;
+      }
+    }
+  }
   if (datetime_format == UNKNOWN && isdigit(cpstr[0]) && isdigit(cpstr[1]) &&
       isdigit(cpstr[2]) && isdigit(cpstr[3])) {
     if (isdigit(cpstr[4])) {
@@ -626,6 +642,54 @@ bool DateTime::set(const String &datetimestr) {
       tmp_time_tm.tm_sec = atoi(cpstr + col);
       break;
 
+    case INTERNALDATE: // "8-Jul-2009 10:32:11 +0900"
+      col = 0;
+      tmp_time_tm.tm_mday = atoi(cpstr);
+      while (cpstr[col] != '-' && cpstr[col] != '\0') {
+        col++;
+      }
+      if (cpstr[col] == '\0') {
+        break;
+      }
+      col++;
+      for (i = 0; i < 12; i++) {
+        if (!strncasecmp(cpstr+col, AMONTH[i], strlen(AMONTH[i]))) {
+          tmp_time_tm.tm_mon = i;
+          col += strlen(AMONTH[i]);
+          break;
+        }
+      }
+      if (cpstr[col] == '-') {
+        col++;
+      }
+      year = atoi(cpstr + col);
+      if (1900 < year) {
+        year = year-1900;
+      }
+      tmp_time_tm.tm_year = year;
+      while (isdigit(cpstr[col])) {
+        col++;
+      }
+      while (cpstr[col] == ',' || cpstr[col] == ' ') {
+        col++;
+      }
+      tmp_time_tm.tm_hour = atoi(cpstr + col);
+      while (isdigit(cpstr[col])) {
+        col++;
+      }
+      if (cpstr[col] == ':') {
+        col++;
+      }
+      tmp_time_tm.tm_min = atoi(cpstr + col);
+      while (isdigit(cpstr[col])) {
+        col++;
+      }
+      if (cpstr[col] == ':') {
+        col++;
+      }
+      tmp_time_tm.tm_sec = atoi(cpstr + col);
+      break;
+
     case ORIGINAL1: // "2008-01-02 10:55:30 +09:00"
       strncpy(buf, cpstr, 4);
       buf[4] = '\0';
@@ -638,9 +702,12 @@ bool DateTime::set(const String &datetimestr) {
       tmp_time_tm.tm_mday = atoi(buf);
 
       col = 10;
-      while (cpstr[col] == ' ') {
+      while (cpstr[col] == ' ' && cpstr[col] != '\0') {
         col++;
       }
+      if (cpstr[col] == '\0') {
+        break;
+      }
       tmp_time_tm.tm_hour = atoi(cpstr + col);
       while (isdigit(cpstr[col])) {
         col++;
