@@ -177,12 +177,11 @@ bool Socket::connect(const char *host, const char *port, bool ssl) {
   for (ai = res; ai; ai = ai->ai_next) {
     (*this).dstSocket = socket(ai->ai_family, ai->ai_socktype, ai->ai_protocol);
     if ((*this).dstSocket < 0) {
-      (*this).nErrno = -1;
-      return false;
+      continue;
     }
 
     // try connect
-    if (0 <= ::connect((*this).dstSocket, ai->ai_addr, ai->ai_addrlen)) {
+    if (::connect((*this).dstSocket, ai->ai_addr, ai->ai_addrlen) == 0) {
       break;
     }
 
@@ -191,11 +190,12 @@ bool Socket::connect(const char *host, const char *port, bool ssl) {
     (*this).dstSocket = -1;
     continue;
   }
+  freeaddrinfo(res);
   if ((*this).dstSocket < 0) {
+    (*this).nErrno = -1;
     return false;
   }
   (*this).nErrno = 0;
-  freeaddrinfo(res);
 #else
   // resolve server name
   addr = inet_addr(destination);
