@@ -122,13 +122,16 @@ int main(int argc, char *argv[]) {
  */
 int test1() {
   // Declare Strings
-  String str_a, str_b, str_c, str_d;
+  String str_a, str_b, str_c, str_d, str_e;
 
   // Set Values
   str_a = "You get married";                         // Set String
   str_b = 100 * 10000;                               // Set String By Number
   str_c = str_a + " and have " + str_b + " kids.";   // Set String Combination
   str_d.sprintf("%s %s", str_b.c_str(), "kids");     // Set Format String
+#if __MD5 == 1
+  str_e = str_c.crypt();
+#endif
 
   // Expected Results
   // str_a = You get married
@@ -136,6 +139,7 @@ int test1() {
   // str_c = You get married and have 1000000 kids.
   // str_d = 1000000 kids
   // str_d.len() = 12
+  // str_e = (crypted string)
 
   if (strcmp(str_a.c_str(), "You get married") != 0) {
     fprintf(stderr, "Error: Test1 #1\n");
@@ -172,10 +176,20 @@ int test1() {
     return -1;
   }
 
+#if __MD5 == 1
+  if (strcmp(str_e.decrypt().c_str(), str_c.c_str()) != 0) {
+    fprintf(stderr, "Error: Test1 #8\n");
+    return -1;
+  }
+#endif
+
   // Clear Allocated Memories (option)
   str_b.clear();
   str_c.clear();
   str_d.clear();
+#if __MD5 == 1
+  str_e.clear();
+#endif
 
   return 0;
 }
@@ -238,7 +252,7 @@ int test2() {
 int test3() {
   // Declare Strings
   String str_a, str_b, str_c, str_d, str_e, str_f, str_g, str_h, str_i, str_j,
-         str_k, str_l, str_m, str_n;
+         str_k, str_l, str_m, str_n, str_o;
 
   // Set Values
   str_a = "This is a pen.";                          // Set String
@@ -258,6 +272,12 @@ int test3() {
   str_l = str_k.unescapeHTML();                      // Decoded String
   str_m = "abc\r\ndef\r";                            // String with a return code
   str_n = str_m.changeReturnCode("ABC");             // change return codes
+#if __MD5 == 1
+  // CRAM-MD5 responce
+  str_o = "password";
+  str_o = str_o.cramMd5("account",
+          "PEMzN0QxRDA5QkREMURBRjQ5NjI5REFCQzE0QzdCMDJBQHZpc2lvbj4=");
+#endif
 
   // Expected Results
   // str_a = This is a pen.
@@ -269,11 +289,12 @@ int test3() {
   // str_g = =?ISO-2022-JP?B?SGUgaXMgGyRCJVolcyVaJXMbKEIgdGhlIHBlbmd1aW4u?=
   // str_h = He is \xA5\xDA\xA5\xF3\xA5\xDA\xA5\xF3 the <penguin>.
   // str_i = He is \xA5\xDA\xA5\xF3\xA5\xDA\xA5\xF3 the &lt;penguin&gt;.
-  // str_j = 26DF8D1FF25025DBC9205416A75C7A80
+  // str_j = 26df8d1ff25025dbc9205416a75c7a80
   // str_k = hello&quot&#34;&#x22&copyworld
   // str_l = hello"""\xC2\xA9world
   // str_m = abc\r\ndef\r
   // str_n = abcABCdefABC
+  // str_o = YWNjb3VudCA4MTk3M2Q3NTllYWRjMjBjYTNhMGRmZDgxMDQwMDg1ZQ==
 
   if (strcmp(str_a.c_str(), "This is a pen.") != 0) {
     fprintf(stderr, "Error: Test3 #1\n");
@@ -321,7 +342,7 @@ int test3() {
   }
 
 #if __MD5 == 1
-  if (strcmp(str_j.c_str(), "26DF8D1FF25025DBC9205416A75C7A80") != 0) {
+  if (strcmp(str_j.c_str(), "26df8d1ff25025dbc9205416a75c7a80") != 0) {
     fprintf(stderr, "Error: Test3 #10\n");
     return -1;
   }
@@ -337,6 +358,13 @@ int test3() {
     return -1;
   }
 
+#if __MD5 == 1
+  if (strcmp(str_o.c_str(), "YWNjb3VudCA4MTk3M2Q3NTllYWRjMjBjYTNhMGRmZDgxMDQwMDg1ZQ==") != 0) {
+    fprintf(stderr, "Error: Test3 #13\n");
+    return -1;
+  }
+#endif
+
   // Clear Allocated Memories (option)
   str_a.clear();
   str_b.clear();
@@ -346,12 +374,16 @@ int test3() {
   str_f.clear();
   str_g.clear();
   str_h.clear();
-  str_i.clear();
+#if __MD5 == 1
   str_j.clear();
+#endif
   str_k.clear();
   str_l.clear();
   str_m.clear();
   str_n.clear();
+#if __MD5 == 1
+  str_o.clear();
+#endif
 
   return 0;
 }
